"""Framework testing ground — TrustChain across agent ecosystems."""

SUPPORTED_FRAMEWORKS = [
    "crewai",
    "openai_agents",
    "autogen",
    "langgraph",
    "google_adk",
    "elizaos",
    "claude_agent",
    "smolagents",
    "pydantic_ai",
    "semantic_kernel",
    "agno",
    "llamaindex",
]
